@@ -1,11 +1,11 @@
 from rtgym.envs.real_time_env import RealTimeGymInterface, DEFAULT_CONFIG_DICT
 from rtgym.tuto.dummy_drone import DummyRCDrone
 import logging
-from gym.envs.registration import register
+from gymnasium.envs.registration import register
 
 logger = logging.getLogger(__name__)
 
 register(
-    id='real-time-gym-v0',
+    id='real-time-gym-v1',
     entry_point='rtgym.envs:RealTimeEnv',
 )
